@@ -151,7 +151,7 @@ class attributes:
                                       fontdict={'verticalalignment': 'baseline',
                                                 'horizontalalignment': 'left'},
                                       pad=self.cb_top_title_pad)
-                    cbar.ax.title.set_position((self.cb_top_title_x, self.cb_top_title_y))
+                    cbar.ax.title.set_position((self.x_cb_top_title, self.cb_top_title_y))
                     text = cbar.ax.title
                     font = mpl.font_manager.FontProperties(family=self.font, style=self.cb_title_style,
                                                            weight=self.cb_title_weight,
@@ -196,6 +196,10 @@ class attributes:
             if not isinstance(self.y_bounds[1], type(None)):
                 self.y_upper_bound = self.y_bounds[1]
 
+        # Avoid issues with custom_canvas
+        if isinstance(self.x, type(None)) or isinstance(self.y, type(None)):
+            self.resize_axes = False
+
         if self.resize_axes is True:
 
             def bounds(d, u, l, up, lp, v):
@@ -266,7 +270,8 @@ class attributes:
 
             # Draw label
             self.ax.set_xlabel(self.x_label, fontname=self.font, weight=self.x_label_weight,
-                               color=self.workspace_color, size=self.x_label_size, labelpad=self.x_label_pad,
+                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
+                               size=self.x_label_size, labelpad=self.x_label_pad,
                                rotation=self.x_label_rotation)
 
             # Custom coordinates if provided
@@ -281,7 +286,8 @@ class attributes:
 
             # Draw label
             self.ax.set_ylabel(self.y_label, fontname=self.font, weight=self.y_label_weight,
-                               color=self.workspace_color, size=self.y_label_size, labelpad=self.y_label_pad,
+                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
+                               size=self.y_label_size, labelpad=self.y_label_pad,
                                rotation=self.y_label_rotation)
 
             # Custom coordinates if provided
@@ -314,10 +320,10 @@ class attributes:
             if np.all(self.y == self.y[0]):
                 self.fine_tick_locations = False
         if self.fine_tick_locations is True:
-            if not isinstance(self.x, type(None)) and isinstance(self.custom_x_tick_locations, type(None)):
-                self.custom_x_tick_locations = [self.x.min(), self.x.max()]
-            if not isinstance(self.y, type(None)) and isinstance(self.custom_y_tick_locations, type(None)):
-                self.custom_y_tick_locations = [self.y.min(), self.y.max()]
+            if not isinstance(self.x, type(None)) and isinstance(self.x_custom_tick_locations, type(None)):
+                self.x_custom_tick_locations = [self.x.min(), self.x.max()]
+            if not isinstance(self.y, type(None)) and isinstance(self.y_custom_tick_locations, type(None)):
+                self.y_custom_tick_locations = [self.y.min(), self.y.max()]
         """
         Implementation
         """
@@ -330,15 +336,15 @@ class attributes:
         #   Label font and color
         for tick in self.ax.get_xticklabels():
             tick.set_fontname(self.font)
-            tick.set_color(self.workspace_color)
+            tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
         for tick in self.ax.get_yticklabels():
             tick.set_fontname(self.font)
-            tick.set_color(self.workspace_color)
+            tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
         #   Label size
-        if not isinstance(self.tick_label_size_x, type(None)):
-            self.ax.tick_params(axis='x', labelsize=self.tick_label_size_x)
-        if not isinstance(self.tick_label_size_y, type(None)):
-            self.ax.tick_params(axis='y', labelsize=self.tick_label_size_y)
+        if not isinstance(self.x_tick_label_size, type(None)):
+            self.ax.tick_params(axis='x', labelsize=self.x_tick_label_size)
+        if not isinstance(self.y_tick_label_size, type(None)):
+            self.ax.tick_params(axis='y', labelsize=self.y_tick_label_size)
         if not isinstance(self.tick_label_size, type(None)):
             self.ax.tick_params(axis='both', labelsize=self.tick_label_size)
         #   Number and custom position ---------------------------------------------------------------------------------
@@ -358,32 +364,40 @@ class attributes:
         if not isinstance(self.prune, type(None)):
             self.ax.yaxis.set_major_locator(self.plt.MaxNLocator(prune=self.prune))
         #   Float format
-        x_decimals = self.tick_ndecimals if isinstance(self.tick_ndecimals_x, type(None)) \
-                     else self.tick_ndecimals_x
-        y_decimals = self.tick_ndecimals if isinstance(self.tick_ndecimals_y, type(None)) \
-                     else self.tick_ndecimals_y
+        x_decimals = self.tick_ndecimals if isinstance(self.x_tick_ndecimals, type(None)) \
+                     else self.x_tick_ndecimals
+        y_decimals = self.tick_ndecimals if isinstance(self.y_tick_ndecimals, type(None)) \
+                     else self.y_tick_ndecimals
         float_format_x = '%.' + str(x_decimals) + 'f'
         float_format_y = '%.' + str(y_decimals) + 'f'
         self.ax.xaxis.set_major_formatter(FormatStrFormatter(float_format_x))
         self.ax.yaxis.set_major_formatter(FormatStrFormatter(float_format_y))
         #   Custom tick positions
-        if not isinstance(self.custom_x_tick_locations, type(None)):
-            # Previous version: set_xticklabels()
-            self.ax.set_xticks(np.linspace(self.custom_x_tick_locations[0], self.custom_x_tick_locations[1], self.x_tick_number),
-                               # fontname=self.font
+        if not isinstance(self.x_custom_tick_locations, type(None)):
+            self.ax.set_xticks(np.linspace(self.x_custom_tick_locations[0],
+                                           self.x_custom_tick_locations[1],
+                                           self.x_tick_number),
                                )
-        if not isinstance(self.custom_y_tick_locations, type(None)):
-            # Previous version: set_yticklabels()
-            self.ax.set_yticks(np.linspace(self.custom_y_tick_locations[0], self.custom_y_tick_locations[1], self.y_tick_number),
-                               # fontname=self.font
+        if not isinstance(self.y_custom_tick_locations, type(None)):
+            self.ax.set_yticks(np.linspace(self.y_custom_tick_locations[0],
+                                           self.y_custom_tick_locations[1],
+                                           self.y_tick_number),
                                )
         #   Custom tick labels
-        if not isinstance(self.custom_x_tick_labels, type(None)):
-            self.ax.set_xticklabels(self.custom_x_tick_labels)
-        if not isinstance(self.custom_y_tick_labels, type(None)):
-            self.ax.set_yticklabels(self.custom_y_tick_labels)
+        if not isinstance(self.x_custom_tick_labels, type(None)):
+            if len(self.x_custom_tick_labels) == 2 and len(self.x_custom_tick_labels) != self.x_tick_number:
+                self.x_custom_tick_labels = np.linspace(self.x_custom_tick_labels[0],
+                                                        self.x_custom_tick_labels[1],
+                                                        self.x_tick_number)
+            self.ax.set_xticklabels(self.x_custom_tick_labels)
+        if not isinstance(self.y_custom_tick_labels, type(None)):
+            if len(self.y_custom_tick_labels) == 2 and len(self.y_custom_tick_labels) != self.y_tick_number:
+                self.y_custom_tick_labels = np.linspace(self.y_custom_tick_labels[0],
+                                                        self.y_custom_tick_labels[1],
+                                                        self.y_tick_number)
+            self.ax.set_yticklabels(self.y_custom_tick_labels)
         #       Date tick labels
-        if self.date_tick_labels_x is True:
+        if self.x_date_tick_labels is True:
             fmtd = pd.date_range(start=self.x[0], end=self.x[-1], periods=self.x_tick_number)
             fmtd = [dt.datetime.strftime(d, self.date_format) for d in fmtd]
             self.ax.set_xticklabels(fmtd)
@@ -539,8 +553,8 @@ class line(plot, std_input):
     def __init__(self,
                  # Specifics
                  line_width=2,
-                 # Base
-                 x=None, y=None, plot_label=None,
+                 # Input
+                 x=None, y=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -577,11 +591,11 @@ class line(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -589,10 +603,11 @@ class line(plot, std_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -606,6 +621,11 @@ class line(plot, std_input):
         """
         Line plot class
         mpl_plotter - 2D
+
+        Specifics
+        :param line_width: Line width
+
+        Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
                             pip install pyqt5
@@ -651,6 +671,8 @@ class line(plot, std_input):
     def mock(self):
         if isinstance(self.x, type(None)) and isinstance(self.y, type(None)):
             self.x, self.y = MockData().spirograph()
+            if self.norm is True:
+                self.norm = self.y
 
 
 class scatter(plot, std_input):
@@ -658,8 +680,8 @@ class scatter(plot, std_input):
     def __init__(self,
                  # Specifics
                  point_size=5, marker='o',
-                 # Base
-                 x=None, y=None, plot_label=None,
+                 # Input
+                 x=None, y=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -696,11 +718,11 @@ class scatter(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -708,10 +730,11 @@ class scatter(plot, std_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -764,9 +787,9 @@ class heatmap(plot, df_input):
 
     def __init__(self,
                  # Specifics
-                 x=None, y=None, z=None, normvariant='SymLog',
-                 # Base
-                 plot_label=None,
+                 normvariant='SymLog',
+                 # Input
+                 x=None, y=None, z=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -803,11 +826,11 @@ class heatmap(plot, df_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -815,10 +838,11 @@ class heatmap(plot, df_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -877,8 +901,8 @@ class quiver(plot, std_input):
                  # Specifics
                  x=None, y=None, u=None, v=None,
                  rule=None, custom_rule=None, vector_width=0.01, vector_min_shaft=2, vector_length_threshold=0.1,
-                 # Base
-                 plot_label=None,
+                 # Input
+
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -915,11 +939,11 @@ class quiver(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -927,10 +951,11 @@ class quiver(plot, std_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -1007,8 +1032,8 @@ class streamline(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, u=None, v=None, line_width=1, line_density=2,
-                 # Base
-                 plot_label=None,
+                 # Input
+
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -1045,11 +1070,11 @@ class streamline(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -1057,10 +1082,11 @@ class streamline(plot, std_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -1109,9 +1135,9 @@ class streamline(plot, std_input):
             self.x = np.linspace(0, 10, 100)
             self.y = np.linspace(0, 10, 100)
             self.x, self.y = np.meshgrid(self.x, self.y)
-            self.u = np.random.random(100)
-            self.v = np.random.random(100)
-            self.u, self.v = np.meshgrid(self.u, self.v)
+            self.u = np.cos(self.x)
+            self.v = np.cos(self.y)
+            self.color = self.u
 
     def method_rule(self):
         if isinstance(self.color, type(None)):
@@ -1123,10 +1149,9 @@ class fill_area(plot, std_input):
 
     def __init__(self,
                  # Specifics
-                 x=None, y=None, z=None,
                  between=False, below=False, above=False,
-                 # Base
-                 plot_label=None,
+                 # Input
+                 x=None, y=None, z=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -1163,11 +1188,11 @@ class fill_area(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
                  # Tick labels
-                 tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
-                 custom_x_tick_labels=None, custom_y_tick_labels=None,
-                 date_tick_labels_x=False, date_format='%Y-%m-%d',
-                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 tick_label_size=None, x_tick_label_size=None, y_tick_label_size=None,
+                 x_custom_tick_locations=None, y_custom_tick_locations=None, fine_tick_locations=True,
+                 x_custom_tick_labels=None, y_custom_tick_labels=None,
+                 x_date_tick_labels=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, x_tick_ndecimals=None, y_tick_ndecimals=None,
                  x_tick_rotation=None, y_tick_rotation=None,
                  tick_labels_where=(1, 1, 0, 0),
                  # Color bar
@@ -1175,10 +1200,11 @@ class fill_area(plot, std_input):
                  cb_title=None, cb_orientation='vertical',
                  cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0,
                  cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
                  cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
+                 plot_label=None,
                  legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
                  legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
@@ -1253,9 +1279,9 @@ class fill_area(plot, std_input):
             self.y = MockData().boltzman(self.x, 0, 1)
             self.z = 1 - MockData().boltzman(self.x, 0.5, 1)
             line(fig=self.fig, ax=self.ax, x=self.x, y=self.y, color='darkred', line_width=2, grid=self.grid,
-                 plot_label=None)
+                 plot_label=None, backend=self.backend)
             line(fig=self.fig, ax=self.ax, x=self.x, y=self.z, color='darkred', line_width=2, grid=self.grid,
-                 plot_label=None)
+                 plot_label=None, backend=self.backend)
             self.below = True
 
 
